# import pydantic

# remove this check once pydantic 2.0.0 has been around for a while
# I've removed it, it's now over 2 years later - MDC (28/08/2025)
# assert pydantic.VERSION >= "2.0.0", "Please upgrade pydantic to version 2.0.0 or higher."
